# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account_grants.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61\x63\x63ount_grants.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"y\n\x19\x41\x63\x63ountGrantCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\raccount_grant\x18\x02 \x01(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xec\x01\n\x1a\x41\x63\x63ountGrantCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\raccount_grant\x18\x02 \x01(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x16\x41\x63\x63ountGrantGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe6\x01\n\x17\x41\x63\x63ountGrantGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\raccount_grant\x18\x02 \x01(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x19\x41\x63\x63ountGrantDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb7\x01\n\x1a\x41\x63\x63ountGrantDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x17\x41\x63\x63ountGrantListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd1\x01\n\x18\x41\x63\x63ountGrantListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0e\x61\x63\x63ount_grants\x18\x02 \x03(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\xfc\x03\n\x0c\x41\x63\x63ountGrant\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bresource_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12:\n\nstart_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12;\n\x0bvalid_until\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\xe5\x01\n\x0b\x61\x63\x63\x65ss_rule\x18\x06 \x01(\tB\xcf\x01\xf2\xf8\xb3\x07\xc9\x01\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x9e\x01\xea\xf3\xb3\x07\x0b\x61\x63\x63\x65ss_rule\xf2\xf3\xb3\x07\x10\n\x02go\x12\nAccessRule\xf2\xf3\xb3\x07\x18\n\ngo_private\x12\nAccessRule\xf2\xf3\xb3\x07\x1a\n\x0cgo_terraform\x12\nAccessRule\xf2\xf3\xb3\x07\x12\n\x04java\x12\nAccessRule\xf2\xf3\xb3\x07!\n\x0cjson_gateway\x12\x11models.AccessRule\xba\xf4\xb3\x07\x16\x61\x63\x63\x65ssRuleDiffSuppress\xd0\xf4\xb3\x07\x01:(\xfa\xf8\xb3\x07#\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x13!terraform-provider2\xab\x04\n\rAccountGrants\x12s\n\x06\x43reate\x12\x1d.v1.AccountGrantCreateRequest\x1a\x1e.v1.AccountGrantCreateResponse\"*\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/account-grants\x12n\n\x03Get\x12\x1a.v1.AccountGrantGetRequest\x1a\x1b.v1.AccountGrantGetResponse\".\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/account-grants/{id}\x12z\n\x06\x44\x65lete\x12\x1d.v1.AccountGrantDeleteRequest\x1a\x1e.v1.AccountGrantDeleteResponse\"1\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/account-grants/{id}\x12l\n\x04List\x12\x1b.v1.AccountGrantListRequest\x1a\x1c.v1.AccountGrantListResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/account-grants\x1aK\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0c\x41\x63\x63ountGrant\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03\x61g-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerBi\n\x19\x63om.strongdm.api.plumbingB\x15\x41\x63\x63ountGrantsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_ACCOUNTGRANTCREATEREQUEST = DESCRIPTOR.message_types_by_name['AccountGrantCreateRequest']
_ACCOUNTGRANTCREATERESPONSE = DESCRIPTOR.message_types_by_name['AccountGrantCreateResponse']
_ACCOUNTGRANTGETREQUEST = DESCRIPTOR.message_types_by_name['AccountGrantGetRequest']
_ACCOUNTGRANTGETRESPONSE = DESCRIPTOR.message_types_by_name['AccountGrantGetResponse']
_ACCOUNTGRANTDELETEREQUEST = DESCRIPTOR.message_types_by_name['AccountGrantDeleteRequest']
_ACCOUNTGRANTDELETERESPONSE = DESCRIPTOR.message_types_by_name['AccountGrantDeleteResponse']
_ACCOUNTGRANTLISTREQUEST = DESCRIPTOR.message_types_by_name['AccountGrantListRequest']
_ACCOUNTGRANTLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccountGrantListResponse']
_ACCOUNTGRANT = DESCRIPTOR.message_types_by_name['AccountGrant']
AccountGrantCreateRequest = _reflection.GeneratedProtocolMessageType('AccountGrantCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTCREATEREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantCreateRequest)
  })
_sym_db.RegisterMessage(AccountGrantCreateRequest)

AccountGrantCreateResponse = _reflection.GeneratedProtocolMessageType('AccountGrantCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTCREATERESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantCreateResponse)
  })
_sym_db.RegisterMessage(AccountGrantCreateResponse)

AccountGrantGetRequest = _reflection.GeneratedProtocolMessageType('AccountGrantGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTGETREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantGetRequest)
  })
_sym_db.RegisterMessage(AccountGrantGetRequest)

AccountGrantGetResponse = _reflection.GeneratedProtocolMessageType('AccountGrantGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTGETRESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantGetResponse)
  })
_sym_db.RegisterMessage(AccountGrantGetResponse)

AccountGrantDeleteRequest = _reflection.GeneratedProtocolMessageType('AccountGrantDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTDELETEREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantDeleteRequest)
  })
_sym_db.RegisterMessage(AccountGrantDeleteRequest)

AccountGrantDeleteResponse = _reflection.GeneratedProtocolMessageType('AccountGrantDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTDELETERESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantDeleteResponse)
  })
_sym_db.RegisterMessage(AccountGrantDeleteResponse)

AccountGrantListRequest = _reflection.GeneratedProtocolMessageType('AccountGrantListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTLISTREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantListRequest)
  })
_sym_db.RegisterMessage(AccountGrantListRequest)

AccountGrantListResponse = _reflection.GeneratedProtocolMessageType('AccountGrantListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTLISTRESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantListResponse)
  })
_sym_db.RegisterMessage(AccountGrantListResponse)

AccountGrant = _reflection.GeneratedProtocolMessageType('AccountGrant', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANT,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrant)
  })
_sym_db.RegisterMessage(AccountGrant)

_ACCOUNTGRANTS = DESCRIPTOR.services_by_name['AccountGrants']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025AccountGrantsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _ACCOUNTGRANTCREATEREQUEST.fields_by_name['account_grant']._options = None
  _ACCOUNTGRANTCREATEREQUEST.fields_by_name['account_grant']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTCREATERESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTGRANTCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTCREATERESPONSE.fields_by_name['account_grant']._options = None
  _ACCOUNTGRANTCREATERESPONSE.fields_by_name['account_grant']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGRANTCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTGRANTCREATERESPONSE._options = None
  _ACCOUNTGRANTCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCOUNTGRANTGETREQUEST.fields_by_name['id']._options = None
  _ACCOUNTGRANTGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTGETRESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTGRANTGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTGETRESPONSE.fields_by_name['account_grant']._options = None
  _ACCOUNTGRANTGETRESPONSE.fields_by_name['account_grant']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTGETRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGRANTGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTGRANTGETRESPONSE._options = None
  _ACCOUNTGRANTGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCOUNTGRANTDELETEREQUEST.fields_by_name['id']._options = None
  _ACCOUNTGRANTDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTDELETERESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTGRANTDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGRANTDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTGRANTDELETERESPONSE._options = None
  _ACCOUNTGRANTDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCOUNTGRANTLISTREQUEST.fields_by_name['filter']._options = None
  _ACCOUNTGRANTLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANTLISTRESPONSE.fields_by_name['account_grants']._options = None
  _ACCOUNTGRANTLISTRESPONSE.fields_by_name['account_grants']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCOUNTGRANTLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGRANTLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTGRANT.fields_by_name['id']._options = None
  _ACCOUNTGRANT.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANT.fields_by_name['resource_id']._options = None
  _ACCOUNTGRANT.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTGRANT.fields_by_name['account_id']._options = None
  _ACCOUNTGRANT.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTGRANT.fields_by_name['start_from']._options = None
  _ACCOUNTGRANT.fields_by_name['start_from']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANT.fields_by_name['valid_until']._options = None
  _ACCOUNTGRANT.fields_by_name['valid_until']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGRANT.fields_by_name['access_rule']._options = None
  _ACCOUNTGRANT.fields_by_name['access_rule']._serialized_options = b'\362\370\263\007\311\001\260\363\263\007\001\312\363\263\007\236\001\352\363\263\007\013access_rule\362\363\263\007\020\n\002go\022\nAccessRule\362\363\263\007\030\n\ngo_private\022\nAccessRule\362\363\263\007\032\n\014go_terraform\022\nAccessRule\362\363\263\007\022\n\004java\022\nAccessRule\362\363\263\007!\n\014json_gateway\022\021models.AccessRule\272\364\263\007\026accessRuleDiffSuppress\320\364\263\007\001'
  _ACCOUNTGRANT._options = None
  _ACCOUNTGRANT._serialized_options = b'\372\370\263\007#\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\023!terraform-provider'
  _ACCOUNTGRANTS._options = None
  _ACCOUNTGRANTS._serialized_options = b'\312\371\263\007\021\302\371\263\007\014AccountGrant\312\371\263\007\010\322\371\263\007\003ag-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _ACCOUNTGRANTS.methods_by_name['Create']._options = None
  _ACCOUNTGRANTS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\027\252\363\263\007\022/v1/account-grants'
  _ACCOUNTGRANTS.methods_by_name['Get']._options = None
  _ACCOUNTGRANTS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\034\252\363\263\007\027/v1/account-grants/{id}'
  _ACCOUNTGRANTS.methods_by_name['Delete']._options = None
  _ACCOUNTGRANTS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\034\252\363\263\007\027/v1/account-grants/{id}'
  _ACCOUNTGRANTS.methods_by_name['List']._options = None
  _ACCOUNTGRANTS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/account-grants'
  _ACCOUNTGRANTCREATEREQUEST._serialized_start=88
  _ACCOUNTGRANTCREATEREQUEST._serialized_end=209
  _ACCOUNTGRANTCREATERESPONSE._serialized_start=212
  _ACCOUNTGRANTCREATERESPONSE._serialized_end=448
  _ACCOUNTGRANTGETREQUEST._serialized_start=450
  _ACCOUNTGRANTGETREQUEST._serialized_end=536
  _ACCOUNTGRANTGETRESPONSE._serialized_start=539
  _ACCOUNTGRANTGETRESPONSE._serialized_end=769
  _ACCOUNTGRANTDELETEREQUEST._serialized_start=771
  _ACCOUNTGRANTDELETEREQUEST._serialized_end=863
  _ACCOUNTGRANTDELETERESPONSE._serialized_start=866
  _ACCOUNTGRANTDELETERESPONSE._serialized_end=1049
  _ACCOUNTGRANTLISTREQUEST._serialized_start=1051
  _ACCOUNTGRANTLISTREQUEST._serialized_end=1143
  _ACCOUNTGRANTLISTRESPONSE._serialized_start=1146
  _ACCOUNTGRANTLISTRESPONSE._serialized_end=1355
  _ACCOUNTGRANT._serialized_start=1358
  _ACCOUNTGRANT._serialized_end=1866
  _ACCOUNTGRANTS._serialized_start=1869
  _ACCOUNTGRANTS._serialized_end=2424
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tags.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntags.proto\x12\x02v1\x1a\roptions.proto\"\xda\x02\n\x04Tags\x12\x1c\n\x05pairs\x18\x01 \x03(\x0b\x32\r.v1.Tags.Pair\x1a\x42\n\x04Pair\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x1d\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\r!json_gateway:\xef\x01\xfa\xf8\xb3\x07\xe9\x01\xca\xf3\xb3\x07\xcb\x01\xea\xf3\xb3\x07\x04tags\xf2\xf3\xb3\x07\n\n\x02go\x12\x04Tags\xf2\xf3\xb3\x07\x12\n\ngo_private\x12\x04Tags\xf2\xf3\xb3\x07\x14\n\x0cgo_terraform\x12\x04Tags\xf2\xf3\xb3\x07%\n\x04java\x12\x1djava.util.Map<String, String>\xf2\xf3\xb3\x07\x1d\n\x12terraform-provider\x12\x07TypeMap\xf2\xf3\xb3\x07!\n\x0cjson_gateway\x12\x11map[string]string\xfa\xf3\xb3\x07\x0ctagsElemType\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\r!json_gateway\"F\n\x03Tag\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05value\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42`\n\x19\x63om.strongdm.api.plumbingB\x0cTagsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_TAGS = DESCRIPTOR.message_types_by_name['Tags']
_TAGS_PAIR = _TAGS.nested_types_by_name['Pair']
_TAG = DESCRIPTOR.message_types_by_name['Tag']
Tags = _reflection.GeneratedProtocolMessageType('Tags', (_message.Message,), {

  'Pair' : _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), {
    'DESCRIPTOR' : _TAGS_PAIR,
    '__module__' : 'tags_pb2'
    # @@protoc_insertion_point(class_scope:v1.Tags.Pair)
    })
  ,
  'DESCRIPTOR' : _TAGS,
  '__module__' : 'tags_pb2'
  # @@protoc_insertion_point(class_scope:v1.Tags)
  })
_sym_db.RegisterMessage(Tags)
_sym_db.RegisterMessage(Tags.Pair)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'tags_pb2'
  # @@protoc_insertion_point(class_scope:v1.Tag)
  })
_sym_db.RegisterMessage(Tag)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\014TagsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _TAGS_PAIR._options = None
  _TAGS_PAIR._serialized_options = b'\372\370\263\007\030\322\363\263\007\001*\322\363\263\007\r!json_gateway'
  _TAGS._options = None
  _TAGS._serialized_options = b'\372\370\263\007\351\001\312\363\263\007\313\001\352\363\263\007\004tags\362\363\263\007\n\n\002go\022\004Tags\362\363\263\007\022\n\ngo_private\022\004Tags\362\363\263\007\024\n\014go_terraform\022\004Tags\362\363\263\007%\n\004java\022\035java.util.Map<String, String>\362\363\263\007\035\n\022terraform-provider\022\007TypeMap\362\363\263\007!\n\014json_gateway\022\021map[string]string\372\363\263\007\014tagsElemType\322\363\263\007\001*\322\363\263\007\r!json_gateway'
  _TAG.fields_by_name['name']._options = None
  _TAG.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _TAG.fields_by_name['value']._options = None
  _TAG.fields_by_name['value']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _TAG._options = None
  _TAG._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _TAGS._serialized_start=34
  _TAGS._serialized_end=380
  _TAGS_PAIR._serialized_start=72
  _TAGS_PAIR._serialized_end=138
  _TAG._serialized_start=382
  _TAG._serialized_end=452
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: approval_workflow_steps.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61pproval_workflow_steps.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\x1egoogle/protobuf/duration.proto\"\x92\x01\n!ApprovalWorkflowStepCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x44\n\x16\x61pproval_workflow_step\x18\x02 \x01(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf9\x01\n\"ApprovalWorkflowStepCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x44\n\x16\x61pproval_workflow_step\x18\x02 \x01(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x1e\x41pprovalWorkflowStepGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xff\x01\n\x1f\x41pprovalWorkflowStepGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x16\x61pproval_workflow_step\x18\x02 \x01(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n!ApprovalWorkflowStepDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcb\x01\n\"ApprovalWorkflowStepDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n\x1f\x41pprovalWorkflowStepListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf6\x01\n ApprovalWorkflowStepListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x45\n\x17\x61pproval_workflow_steps\x18\x02 \x03(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x84\x03\n\x14\x41pprovalWorkflowStep\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x10\x61pproval_flow_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12J\n\nquantifier\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\xb2\xf4\xb3\x07\x04!cli\x12\x65\n\nskip_after\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\xb2\xf4\xb3\x07\x04!cli\x12J\n\nstep_order\x18\x05 \x01(\x05\x42\x36\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\xb2\xf4\xb3\x07\x04!cli:*\x18\x01\xfa\xf8\xb3\x07#\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x13!terraform-provider2\xab\x05\n\x15\x41pprovalWorkflowSteps\x12\x8c\x01\n\x06\x43reate\x12%.v1.ApprovalWorkflowStepCreateRequest\x1a&.v1.ApprovalWorkflowStepCreateResponse\"3\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/approval-workflow-steps\x12\x86\x01\n\x03Get\x12\".v1.ApprovalWorkflowStepGetRequest\x1a#.v1.ApprovalWorkflowStepGetResponse\"6\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07$\xaa\xf3\xb3\x07\x1f/v1/approval-workflow-step/{id}\x12\x8e\x01\n\x06\x44\x65lete\x12%.v1.ApprovalWorkflowStepDeleteRequest\x1a&.v1.ApprovalWorkflowStepDeleteResponse\"5\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/approval-workflow-steps\x12\x85\x01\n\x04List\x12#.v1.ApprovalWorkflowStepListRequest\x1a$.v1.ApprovalWorkflowStepListResponse\"2\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/approval-workflow-steps\x1a\x61\x88\x02\x01\xca\xf9\xb3\x07\x19\xc2\xf9\xb3\x07\x14\x41pprovalWorkflowStep\xca\xf9\xb3\x07\t\xd2\xf9\xb3\x07\x04\x61\x66s-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerBq\n\x19\x63om.strongdm.api.plumbingB\x1d\x41pprovalWorkflowStepsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_APPROVALWORKFLOWSTEPCREATEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepCreateRequest']
_APPROVALWORKFLOWSTEPCREATERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepCreateResponse']
_APPROVALWORKFLOWSTEPGETREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepGetRequest']
_APPROVALWORKFLOWSTEPGETRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepGetResponse']
_APPROVALWORKFLOWSTEPDELETEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepDeleteRequest']
_APPROVALWORKFLOWSTEPDELETERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepDeleteResponse']
_APPROVALWORKFLOWSTEPLISTREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepListRequest']
_APPROVALWORKFLOWSTEPLISTRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepListResponse']
_APPROVALWORKFLOWSTEP = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStep']
ApprovalWorkflowStepCreateRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPCREATEREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepCreateRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepCreateRequest)

ApprovalWorkflowStepCreateResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPCREATERESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepCreateResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepCreateResponse)

ApprovalWorkflowStepGetRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPGETREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepGetRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepGetRequest)

ApprovalWorkflowStepGetResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPGETRESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepGetResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepGetResponse)

ApprovalWorkflowStepDeleteRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPDELETEREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepDeleteRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepDeleteRequest)

ApprovalWorkflowStepDeleteResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPDELETERESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepDeleteResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepDeleteResponse)

ApprovalWorkflowStepListRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepListRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPLISTREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepListRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepListRequest)

ApprovalWorkflowStepListResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepListResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPLISTRESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepListResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepListResponse)

ApprovalWorkflowStep = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStep', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEP,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStep)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStep)

_APPROVALWORKFLOWSTEPS = DESCRIPTOR.services_by_name['ApprovalWorkflowSteps']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\035ApprovalWorkflowStepsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _APPROVALWORKFLOWSTEPCREATEREQUEST.fields_by_name['approval_workflow_step']._options = None
  _APPROVALWORKFLOWSTEPCREATEREQUEST.fields_by_name['approval_workflow_step']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['approval_workflow_step']._options = None
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['approval_workflow_step']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPCREATERESPONSE._options = None
  _APPROVALWORKFLOWSTEPCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['meta']._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['approval_workflow_step']._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['approval_workflow_step']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPGETRESPONSE._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEPDELETEREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPDELETERESPONSE._options = None
  _APPROVALWORKFLOWSTEPDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEPLISTREQUEST.fields_by_name['filter']._options = None
  _APPROVALWORKFLOWSTEPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['approval_workflow_steps']._options = None
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['approval_workflow_steps']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPLISTRESPONSE._options = None
  _APPROVALWORKFLOWSTEPLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEP.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEP.fields_by_name['approval_flow_id']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['approval_flow_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _APPROVALWORKFLOWSTEP.fields_by_name['quantifier']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['quantifier']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider\262\364\263\007\004!cli'
  _APPROVALWORKFLOWSTEP.fields_by_name['skip_after']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['skip_after']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider\262\364\263\007\004!cli'
  _APPROVALWORKFLOWSTEP.fields_by_name['step_order']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['step_order']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider\262\364\263\007\004!cli'
  _APPROVALWORKFLOWSTEP._options = None
  _APPROVALWORKFLOWSTEP._serialized_options = b'\030\001\372\370\263\007#\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\023!terraform-provider'
  _APPROVALWORKFLOWSTEPS._options = None
  _APPROVALWORKFLOWSTEPS._serialized_options = b'\210\002\001\312\371\263\007\031\302\371\263\007\024ApprovalWorkflowStep\312\371\263\007\t\322\371\263\007\004afs-\312\371\263\007\005\350\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _APPROVALWORKFLOWSTEPS.methods_by_name['Create']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007 \252\363\263\007\033/v1/approval-workflow-steps'
  _APPROVALWORKFLOWSTEPS.methods_by_name['Get']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007$\252\363\263\007\037/v1/approval-workflow-step/{id}'
  _APPROVALWORKFLOWSTEPS.methods_by_name['Delete']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007 \252\363\263\007\033/v1/approval-workflow-steps'
  _APPROVALWORKFLOWSTEPS.methods_by_name['List']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007 \252\363\263\007\033/v1/approval-workflow-steps'
  _APPROVALWORKFLOWSTEPCREATEREQUEST._serialized_start=97
  _APPROVALWORKFLOWSTEPCREATEREQUEST._serialized_end=243
  _APPROVALWORKFLOWSTEPCREATERESPONSE._serialized_start=246
  _APPROVALWORKFLOWSTEPCREATERESPONSE._serialized_end=495
  _APPROVALWORKFLOWSTEPGETREQUEST._serialized_start=497
  _APPROVALWORKFLOWSTEPGETREQUEST._serialized_end=591
  _APPROVALWORKFLOWSTEPGETRESPONSE._serialized_start=594
  _APPROVALWORKFLOWSTEPGETRESPONSE._serialized_end=849
  _APPROVALWORKFLOWSTEPDELETEREQUEST._serialized_start=851
  _APPROVALWORKFLOWSTEPDELETEREQUEST._serialized_end=951
  _APPROVALWORKFLOWSTEPDELETERESPONSE._serialized_start=954
  _APPROVALWORKFLOWSTEPDELETERESPONSE._serialized_end=1157
  _APPROVALWORKFLOWSTEPLISTREQUEST._serialized_start=1159
  _APPROVALWORKFLOWSTEPLISTREQUEST._serialized_end=1259
  _APPROVALWORKFLOWSTEPLISTRESPONSE._serialized_start=1262
  _APPROVALWORKFLOWSTEPLISTRESPONSE._serialized_end=1508
  _APPROVALWORKFLOWSTEP._serialized_start=1511
  _APPROVALWORKFLOWSTEP._serialized_end=1899
  _APPROVALWORKFLOWSTEPS._serialized_start=1902
  _APPROVALWORKFLOWSTEPS._serialized_end=2585
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import proxy_cluster_keys_pb2 as proxy__cluster__keys__pb2


class ProxyClusterKeysStub(object):
    """Proxy Cluster Keys are authentication keys for all proxies within a cluster.
    The proxies within a cluster share the same key. One cluster can have
    multiple keys in order to facilitate key rotation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/v1.ProxyClusterKeys/Create',
                request_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyCreateRequest.SerializeToString,
                response_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyCreateResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/v1.ProxyClusterKeys/Get',
                request_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyGetRequest.SerializeToString,
                response_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyGetResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/v1.ProxyClusterKeys/Delete',
                request_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyDeleteRequest.SerializeToString,
                response_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyDeleteResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/v1.ProxyClusterKeys/List',
                request_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyListRequest.SerializeToString,
                response_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyListResponse.FromString,
                )


class ProxyClusterKeysServicer(object):
    """Proxy Cluster Keys are authentication keys for all proxies within a cluster.
    The proxies within a cluster share the same key. One cluster can have
    multiple keys in order to facilitate key rotation.
    """

    def Create(self, request, context):
        """Create registers a new ProxyClusterKey.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get reads one ProxyClusterKey by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete removes a ProxyClusterKey by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """List gets a list of ProxyClusterKeys matching a given set of criteria.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProxyClusterKeysServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyCreateRequest.FromString,
                    response_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyCreateResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyGetRequest.FromString,
                    response_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyGetResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyDeleteRequest.FromString,
                    response_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyDeleteResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=proxy__cluster__keys__pb2.ProxyClusterKeyListRequest.FromString,
                    response_serializer=proxy__cluster__keys__pb2.ProxyClusterKeyListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.ProxyClusterKeys', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProxyClusterKeys(object):
    """Proxy Cluster Keys are authentication keys for all proxies within a cluster.
    The proxies within a cluster share the same key. One cluster can have
    multiple keys in order to facilitate key rotation.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ProxyClusterKeys/Create',
            proxy__cluster__keys__pb2.ProxyClusterKeyCreateRequest.SerializeToString,
            proxy__cluster__keys__pb2.ProxyClusterKeyCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ProxyClusterKeys/Get',
            proxy__cluster__keys__pb2.ProxyClusterKeyGetRequest.SerializeToString,
            proxy__cluster__keys__pb2.ProxyClusterKeyGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ProxyClusterKeys/Delete',
            proxy__cluster__keys__pb2.ProxyClusterKeyDeleteRequest.SerializeToString,
            proxy__cluster__keys__pb2.ProxyClusterKeyDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.ProxyClusterKeys/List',
            proxy__cluster__keys__pb2.ProxyClusterKeyListRequest.SerializeToString,
            proxy__cluster__keys__pb2.ProxyClusterKeyListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright 2020 StrongDM Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# Code generated by protogen. DO NOT EDIT.

import base64
import collections
import copy
import datetime
import functools
import grpc
import hashlib
import hmac
import random
import re
import time
from . import errors
from . import plumbing
from . import svc

from cryptography.hazmat.primitives.asymmetric import rsa, padding
from cryptography.hazmat.primitives import serialization, hashes

# These defaults are taken from AWS. Customization of these values
# is a future step in the API.
DEFAULT_BASE_RETRY_DELAY = 1  # 1 second
DEFAULT_MAX_RETRY_DELAY = 120  # 120 seconds
DEFAULT_RETRY_FACTOR = 1.6
DEFAULT_RETRY_JITTER = 0.2
API_VERSION = '2025-04-14'
USER_AGENT = 'strongdm-sdk-python/16.3.0'

method_regexp = re.compile(r'\W+')


class _ClientCallDetails(
        collections.namedtuple(
            "_ClientCallDetails",
            ("method", "timeout", "metadata", "credentials")),
        grpc.ClientCallDetails,
):
    """ _ClientCallDetails is used to override some of the attributes of the client_call_details in the interceptors"""
    pass


class _EncryptionInterceptor(grpc.UnaryUnaryClientInterceptor):
    """ _EncryptionInterceptor is used to add transparent encryption/decryption support for managed secrets"""
    def __init__(self, client):
        self.client = client
        self.public_key_cache = {}

    def intercept_unary_unary(self, continuation, client_call_details,
                              request):
        method = method_regexp.sub("_", client_call_details.method.lower())
        callback = getattr(self, method, None)
        if callback is not None:
            return callback(continuation, client_call_details, request)
        return continuation(client_call_details, request)

    @functools.cached_property
    def private_key(self):
        return rsa.generate_private_key(
            public_exponent=65537,
            key_size=4096,
        )

    def _encrypt_secret(self, method, continuation, client_call_details,
                        request):
        secret = request.managed_secret
        if len(secret.value) != 0:
            if secret.secret_engine_id not in self.public_key_cache:
                try:
                    # fetch secret engine details to fill up self.public_key_cache
                    # if it fails the call to create/update will fail as well
                    self.client.secret_engines.get(secret.secret_engine_id)
                except errors.RPCError:
                    pass
            key = self.public_key_cache.get(secret.secret_engine_id)
            if key is not None:
                encrypted = key.encrypt(
                    secret.value,
                    padding.OAEP(mgf=padding.MGF1(algorithm=hashes.SHA256()),
                                 algorithm=hashes.SHA256(),
                                 label=None))
                secret.value = encrypted
            client_call_details = _ClientCallDetails(
                method=client_call_details.method,
                timeout=client_call_details.timeout,
                metadata=self.client.get_metadata(method, request),
                credentials=client_call_details.credentials)
        return continuation(client_call_details, request)

    def _v1_managedsecrets_create(self, continuation, client_call_details,
                                  request):
        return self._encrypt_secret("ManagedSecrets.Create", continuation,
                                    client_call_details, request)

    def _v1_managedsecrets_update(self, continuation, client_call_details,
                                  request):
        return self._encrypt_secret("ManagedSecrets.Update", continuation,
                                    client_call_details, request)

    def _v1_managedsecrets_retrieve(self, continuation, client_call_details,
                                    request):
        if len(request.public_key) != 0:
            return continuation(client_call_details, request)

        privKey = self.private_key
        request.public_key = privKey.public_key().public_bytes(
            serialization.Encoding.PEM,
            serialization.PublicFormat.SubjectPublicKeyInfo)
        client_call_details = _ClientCallDetails(
            method=client_call_details.method,
            timeout=client_call_details.timeout,
            metadata=self.client.get_metadata("ManagedSecrets.Retrieve",
                                              request),
            credentials=client_call_details.credentials)
        resp = continuation(client_call_details, request)
        if resp.code() != grpc.StatusCode.OK:
            return resp
        result = resp.result()
        plaintext = privKey.decrypt(
            result.managed_secret.value,
            padding.OAEP(
                mgf=padding.MGF1(algorithm=hashes.SHA256()),
                algorithm=hashes.SHA256(),
                label=None,
            ))
        result.managed_secret.value = plaintext
        return resp

    def _v1_secretengines_get(self, continuation, client_call_details,
                              request):
        response = continuation(client_call_details, request)
        if response.code() != grpc.StatusCode.OK:
            return response
        result = response.result()
        engine = plumbing.convert_secret_engine_to_porcelain(
            result.secret_engine)
        engineKey = serialization.load_pem_public_key(engine.public_key)
        self.public_key_cache[engine.id] = engineKey
        return response

    def _v1_secretengines_list(self, continuation, client_call_details,
                               request):
        response = continuation(client_call_details, request)
        if response.code() != grpc.StatusCode.OK:
            return response
        result = response.result()
        for plumbing_engine in result.secret_engines:
            engine = plumbing.convert_secret_engine_to_porcelain(
                plumbing_engine)
            engineKey = serialization.load_pem_public_key(engine.public_key)
            self.public_key_cache[engine.id] = engineKey
        return response


class Client:
    '''Client interacts with the strongDM API.'''
    def __init__(self,
                 api_access_key,
                 api_secret,
                 host='app.strongdm.com:443',
                 insecure=False,
                 retry_rate_limit_errors=True,
                 page_limit=0):
        '''
        Create a new Client.

        - api_access_key: the access key to authenticate with strongDM
        - api_secret: the secret key to authenticate with strongDM
        '''
        self.api_access_key = api_access_key.strip()
        self.api_secret = base64.b64decode(api_secret.strip())
        self.base_retry_delay = DEFAULT_BASE_RETRY_DELAY
        self.max_retry_delay = DEFAULT_MAX_RETRY_DELAY
        self.retry_factor = DEFAULT_RETRY_FACTOR
        self.retry_jitter = DEFAULT_RETRY_JITTER
        self.retry_rate_limit_errors = retry_rate_limit_errors
        self.snapshot_datetime = None
        self.page_limit = page_limit

        try:
            if insecure:
                channel = grpc.insecure_channel(host)
            else:
                creds = grpc.ssl_channel_credentials()
                channel = grpc.secure_channel(host, creds)
        except Exception as e:
            raise plumbing.convert_error_to_porcelain(e) from e
        channel = grpc.intercept_channel(channel, _EncryptionInterceptor(self))
        self.channel = channel
        self.access_requests = svc.AccessRequests(channel, self)
        '''
         AccessRequests are requests for access to a resource that may match a Workflow.

        See `strongdm.svc.AccessRequests`.
        '''
        self.access_request_events_history = svc.AccessRequestEventsHistory(
            channel, self)
        '''
         AccessRequestEventsHistory provides records of all changes to the state of an AccessRequest.

        See `strongdm.svc.AccessRequestEventsHistory`.
        '''
        self.access_requests_history = svc.AccessRequestsHistory(channel, self)
        '''
         AccessRequestsHistory provides records of all changes to the state of an AccessRequest.

        See `strongdm.svc.AccessRequestsHistory`.
        '''
        self.account_attachments = svc.AccountAttachments(channel, self)
        '''
         AccountAttachments assign an account to a role.

        See `strongdm.svc.AccountAttachments`.
        '''
        self.account_attachments_history = svc.AccountAttachmentsHistory(
            channel, self)
        '''
         AccountAttachmentsHistory records all changes to the state of an AccountAttachment.

        See `strongdm.svc.AccountAttachmentsHistory`.
        '''
        self.account_grants = svc.AccountGrants(channel, self)
        '''
         AccountGrants assign a resource directly to an account, giving the account the permission to connect to that resource.

        See `strongdm.svc.AccountGrants`.
        '''
        self.account_grants_history = svc.AccountGrantsHistory(channel, self)
        '''
         AccountGrantsHistory records all changes to the state of an AccountGrant.

        See `strongdm.svc.AccountGrantsHistory`.
        '''
        self.account_permissions = svc.AccountPermissions(channel, self)
        '''
         AccountPermissions records the granular permissions accounts have, allowing them to execute
         relevant commands via StrongDM's APIs.

        See `strongdm.svc.AccountPermissions`.
        '''
        self.account_resources = svc.AccountResources(channel, self)
        '''
         AccountResources enumerates the resources to which accounts have access.
         The AccountResources service is read-only.

        See `strongdm.svc.AccountResources`.
        '''
        self.account_resources_history = svc.AccountResourcesHistory(
            channel, self)
        '''
         AccountResourcesHistory records all changes to the state of a AccountResource.

        See `strongdm.svc.AccountResourcesHistory`.
        '''
        self.accounts = svc.Accounts(channel, self)
        '''
         Accounts are users that have access to strongDM. There are two types of accounts:
         1. **Users:** humans who are authenticated through username and password or SSO.
         2. **Service Accounts:** machines that are authenticated using a service token.
         3. **Tokens** are access keys with permissions that can be used for authentication.

        See `strongdm.svc.Accounts`.
        '''
        self.accounts_groups = svc.AccountsGroups(channel, self)
        '''
         An AccountGroup links an account and a group.

        See `strongdm.svc.AccountsGroups`.
        '''
        self.accounts_groups_history = svc.AccountsGroupsHistory(channel, self)
        '''
         AccountsGroupsHistory records all changes to the state of an AccountGroup.

        See `strongdm.svc.AccountsGroupsHistory`.
        '''
        self.accounts_history = svc.AccountsHistory(channel, self)
        '''
         AccountsHistory records all changes to the state of an Account.

        See `strongdm.svc.AccountsHistory`.
        '''
        self.activities = svc.Activities(channel, self)
        '''
         An Activity is a record of an action taken against a strongDM deployment, e.g.
         a user creation, resource deletion, sso configuration change, etc. The Activities
         service is read-only.

        See `strongdm.svc.Activities`.
        '''
        self.approval_workflow_approvers = svc.ApprovalWorkflowApprovers(
            channel, self)
        '''
         ApprovalWorkflowApprovers link approval workflow approvers to an ApprovalWorkflowStep

        See `strongdm.svc.ApprovalWorkflowApprovers`.
        '''
        self.approval_workflow_approvers_history = svc.ApprovalWorkflowApproversHistory(
            channel, self)
        '''
         ApprovalWorkflowApproversHistory records all changes to the state of an ApprovalWorkflowApprover.

        See `strongdm.svc.ApprovalWorkflowApproversHistory`.
        '''
        self.approval_workflow_steps = svc.ApprovalWorkflowSteps(channel, self)
        '''
         ApprovalWorkflowSteps link approval workflow steps to an ApprovalWorkflow

        See `strongdm.svc.ApprovalWorkflowSteps`.
        '''
        self.approval_workflow_steps_history = svc.ApprovalWorkflowStepsHistory(
            channel, self)
        '''
         ApprovalWorkflowStepsHistory records all changes to the state of an ApprovalWorkflowStep.

        See `strongdm.svc.ApprovalWorkflowStepsHistory`.
        '''
        self.approval_workflows = svc.ApprovalWorkflows(channel, self)
        '''
         ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized
         approvers and be approved or denied.

        See `strongdm.svc.ApprovalWorkflows`.
        '''
        self.approval_workflows_history = svc.ApprovalWorkflowsHistory(
            channel, self)
        '''
         ApprovalWorkflowsHistory records all changes to the state of an ApprovalWorkflow.

        See `strongdm.svc.ApprovalWorkflowsHistory`.
        '''
        self.control_panel = svc.ControlPanel(channel, self)
        '''
         ControlPanel contains all administrative controls.

        See `strongdm.svc.ControlPanel`.
        '''
        self.discovery_connectors = svc.DiscoveryConnectors(channel, self)
        '''
         A Discovery Connector is a configuration object for performing Resource
         Scans in remote systems such as AWS, GCP, Azure, and other systems.

        See `strongdm.svc.DiscoveryConnectors`.
        '''
        self.roles = svc.Roles(channel, self)
        '''
         A Role has a list of access rules which determine which Resources the members
         of the Role have access to. An Account can be a member of multiple Roles via
         AccountAttachments.

        See `strongdm.svc.Roles`.
        '''
        self.groups = svc.Groups(channel, self)
        '''
         A Group is a set of principals.

        See `strongdm.svc.Groups`.
        '''
        self.groups_history = svc.GroupsHistory(channel, self)
        '''
         GroupsHistory records all changes to the state of a Group.

        See `strongdm.svc.GroupsHistory`.
        '''
        self.groups_roles = svc.GroupsRoles(channel, self)
        '''
         A GroupRole is an assignment of a Group to a Role.

        See `strongdm.svc.GroupsRoles`.
        '''
        self.groups_roles_history = svc.GroupsRolesHistory(channel, self)
        '''
         GroupsRolesHistory records all changes to the state of a GroupRole.

        See `strongdm.svc.GroupsRolesHistory`.
        '''
        self.health_checks = svc.HealthChecks(channel, self)
        '''
         HealthChecks lists the last healthcheck between each node and resource.
         Note the unconventional capitalization here is to prevent having a collision with GRPC

        See `strongdm.svc.HealthChecks`.
        '''
        self.identity_aliases = svc.IdentityAliases(channel, self)
        '''
         IdentityAliases assign an alias to an account within an IdentitySet.
         The alias is used as the username when connecting to a identity supported resource.

        See `strongdm.svc.IdentityAliases`.
        '''
        self.identity_aliases_history = svc.IdentityAliasesHistory(
            channel, self)
        '''
         IdentityAliasesHistory records all changes to the state of a IdentityAlias.

        See `strongdm.svc.IdentityAliasesHistory`.
        '''
        self.identity_sets = svc.IdentitySets(channel, self)
        '''
         A IdentitySet is a named grouping of Identity Aliases for Accounts.
         An Account's relationship to a IdentitySet is defined via IdentityAlias objects.

        See `strongdm.svc.IdentitySets`.
        '''
        self.identity_sets_history = svc.IdentitySetsHistory(channel, self)
        '''
         IdentitySetsHistory records all changes to the state of a IdentitySet.

        See `strongdm.svc.IdentitySetsHistory`.
        '''
        self.managed_secrets = svc.ManagedSecrets(channel, self)
        '''
         ManagedSecret is a private vertical for creating, reading, updating,
         deleting, listing and rotating the managed secrets in the secrets engines as
         an authenticated user.

        See `strongdm.svc.ManagedSecrets`.
        '''
        self.nodes = svc.Nodes(channel, self)
        '''
         Nodes make up the StrongDM network, and allow your users to connect securely to your resources.
         There are three types of nodes:
         1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
         2. **Gateway:** a relay that also listens for connections from StrongDM clients
         3. **Proxy Cluster:** a cluster of workers that together mediate access from clients to resources

        See `strongdm.svc.Nodes`.
        '''
        self.nodes_history = svc.NodesHistory(channel, self)
        '''
         NodesHistory records all changes to the state of a Node.

        See `strongdm.svc.NodesHistory`.
        '''
        self.organization_history = svc.OrganizationHistory(channel, self)
        '''
         OrganizationHistory records all changes to the state of an Organization.

        See `strongdm.svc.OrganizationHistory`.
        '''
        self.peering_group_nodes = svc.PeeringGroupNodes(channel, self)
        '''
         PeeringGroupNodes provides the building blocks necessary to obtain attach a node to a peering group.

        See `strongdm.svc.PeeringGroupNodes`.
        '''
        self.peering_group_peers = svc.PeeringGroupPeers(channel, self)
        '''
         PeeringGroupPeers provides the building blocks necessary to link two peering groups.

        See `strongdm.svc.PeeringGroupPeers`.
        '''
        self.peering_group_resources = svc.PeeringGroupResources(channel, self)
        '''
         PeeringGroupResources provides the building blocks necessary to obtain attach a resource to a peering group.

        See `strongdm.svc.PeeringGroupResources`.
        '''
        self.peering_groups = svc.PeeringGroups(channel, self)
        '''
         PeeringGroups provides the building blocks necessary to obtain explicit network topology and routing.

        See `strongdm.svc.PeeringGroups`.
        '''
        self.policies = svc.Policies(channel, self)
        '''
         Policies are the collection of one or more statements that enforce fine-grained access
         control for the users of an organization.

        See `strongdm.svc.Policies`.
        '''
        self.policies_history = svc.PoliciesHistory(channel, self)
        '''
         PoliciesHistory records all changes to the state of a Policy.

        See `strongdm.svc.PoliciesHistory`.
        '''
        self.proxy_cluster_keys = svc.ProxyClusterKeys(channel, self)
        '''
         Proxy Cluster Keys are authentication keys for all proxies within a cluster.
         The proxies within a cluster share the same key. One cluster can have
         multiple keys in order to facilitate key rotation.

        See `strongdm.svc.ProxyClusterKeys`.
        '''
        self.queries = svc.Queries(channel, self)
        '''
         A Query is a record of a single client request to a resource, such as a SQL query.
         Long-running SSH, RDP, or Kubernetes interactive sessions also count as queries.
         The Queries service is read-only.

        See `strongdm.svc.Queries`.
        '''
        self.remote_identities = svc.RemoteIdentities(channel, self)
        '''
         RemoteIdentities assign a resource directly to an account, giving the account the permission to connect to that resource.

        See `strongdm.svc.RemoteIdentities`.
        '''
        self.remote_identities_history = svc.RemoteIdentitiesHistory(
            channel, self)
        '''
         RemoteIdentitiesHistory records all changes to the state of a RemoteIdentity.

        See `strongdm.svc.RemoteIdentitiesHistory`.
        '''
        self.remote_identity_groups = svc.RemoteIdentityGroups(channel, self)
        '''
         A RemoteIdentityGroup is a named grouping of Remote Identities for Accounts.
         An Account's relationship to a RemoteIdentityGroup is defined via RemoteIdentity objects.

        See `strongdm.svc.RemoteIdentityGroups`.
        '''
        self.remote_identity_groups_history = svc.RemoteIdentityGroupsHistory(
            channel, self)
        '''
         RemoteIdentityGroupsHistory records all changes to the state of a RemoteIdentityGroup.

        See `strongdm.svc.RemoteIdentityGroupsHistory`.
        '''
        self.replays = svc.Replays(channel, self)
        '''
         A Replay captures the data transferred over a long-running SSH, RDP, or Kubernetes interactive session
         (otherwise referred to as a query). The Replays service is read-only.

        See `strongdm.svc.Replays`.
        '''
        self.resources = svc.Resources(channel, self)
        '''
         Resources are databases, servers, clusters, websites, or clouds that strongDM
         delegates access to.

        See `strongdm.svc.Resources`.
        '''
        self.resources_history = svc.ResourcesHistory(channel, self)
        '''
         ResourcesHistory records all changes to the state of a Resource.

        See `strongdm.svc.ResourcesHistory`.
        '''
        self.role_resources = svc.RoleResources(channel, self)
        '''
         RoleResources enumerates the resources to which roles have access.
         The RoleResources service is read-only.

        See `strongdm.svc.RoleResources`.
        '''
        self.role_resources_history = svc.RoleResourcesHistory(channel, self)
        '''
         RoleResourcesHistory records all changes to the state of a RoleResource.

        See `strongdm.svc.RoleResourcesHistory`.
        '''
        self.roles_history = svc.RolesHistory(channel, self)
        '''
         RolesHistory records all changes to the state of a Role.

        See `strongdm.svc.RolesHistory`.
        '''
        self.secret_stores = svc.SecretStores(channel, self)
        '''
         SecretStores are servers where resource secrets (passwords, keys) are stored.

        See `strongdm.svc.SecretStores`.
        '''
        self.secret_engines = svc.SecretEngines(channel, self)
        '''


        See `strongdm.svc.SecretEngines`.
        '''
        self.secret_store_healths = svc.SecretStoreHealths(channel, self)
        '''
         SecretStoreHealths exposes health states for secret stores.

        See `strongdm.svc.SecretStoreHealths`.
        '''
        self.secret_stores_history = svc.SecretStoresHistory(channel, self)
        '''
         SecretStoresHistory records all changes to the state of a SecretStore.

        See `strongdm.svc.SecretStoresHistory`.
        '''
        self.workflow_approvers = svc.WorkflowApprovers(channel, self)
        '''
         WorkflowApprovers is an account or a role with the ability to approve requests bound to a workflow.

        See `strongdm.svc.WorkflowApprovers`.
        '''
        self.workflow_approvers_history = svc.WorkflowApproversHistory(
            channel, self)
        '''
         WorkflowApproversHistory provides records of all changes to the state of a WorkflowApprover.

        See `strongdm.svc.WorkflowApproversHistory`.
        '''
        self.workflow_roles = svc.WorkflowRoles(channel, self)
        '''
         WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of
         to request access to a resource via the workflow.

        See `strongdm.svc.WorkflowRoles`.
        '''
        self.workflow_roles_history = svc.WorkflowRolesHistory(channel, self)
        '''
         WorkflowRolesHistory provides records of all changes to the state of a WorkflowRole

        See `strongdm.svc.WorkflowRolesHistory`.
        '''
        self.workflows = svc.Workflows(channel, self)
        '''
         Workflows are the collection of rules that define the resources to which access can be requested,
         the users that can request that access, and the mechanism for approving those requests which can either
         be automatic approval or a set of users authorized to approve the requests.

        See `strongdm.svc.Workflows`.
        '''
        self.workflows_history = svc.WorkflowsHistory(channel, self)
        '''
         WorkflowsHistory provides records of all changes to the state of a Workflow.

        See `strongdm.svc.WorkflowsHistory`.
        '''

    def close(self):
        '''Closes this Client and releases all resources held by it.

        Closing the Client will immediately terminate all RPCs active with the
        Client and it is not valid to invoke new RPCs with the Client.

        This method is idempotent.
        '''
        self.channel.close()

    def get_metadata(self, method_name, req):
        return [
            ('x-sdm-authentication', self.api_access_key),
            ('x-sdm-signature', self.sign(method_name,
                                          req.SerializeToString())),
            ('x-sdm-api-version', API_VERSION),
            ('x-sdm-user-agent', USER_AGENT),
        ]

    def sign(self, method_name, request_bytes):
        def hmac_digest(key, msg_byte_string):
            return hmac.new(key, msg=msg_byte_string,
                            digestmod=hashlib.sha256).digest()

        current_utc_date = datetime.datetime.now(
            datetime.timezone.utc).strftime('%Y-%m-%d')
        signing_key = hmac_digest(self.api_secret, current_utc_date.encode())
        signing_key = hmac_digest(signing_key, b'sdm_api_v1')

        hash = hashlib.sha256()

        hash.update(method_name.encode())
        hash.update(b'\n')
        hash.update(request_bytes)

        return base64.b64encode(hmac_digest(signing_key, hash.digest()))

    def exponentialBackoff(self, retries, deadline=None):
        def applyDeadline(delay, deadline):
            if deadline is None:
                return delay
            remaining = deadline - time.time()
            if remaining < 0:
                return 0
            return min(delay, remaining)

        if retries == 0:
            return applyDeadline(self.base_retry_delay, deadline)

        backoff, max_delay = self.base_retry_delay, self.max_retry_delay
        while backoff < max_delay and retries > 0:
            backoff *= self.retry_factor
            retries -= 1

        if backoff > max_delay:
            backoff = max_delay

        # Randomize backoff delays so that if a cluster of requests start at
        # the same time, they won't operate in lockstep.
        backoff *= 1 + self.retry_jitter * (random.random() * 2 - 1)
        if backoff < 0:
            return 0

        return applyDeadline(backoff, deadline)

    def shouldRetry(self, retries, err, deadline=None):
        # Check if we've passed the deadline
        if deadline is not None and time.time() >= deadline:
            return False

        if not isinstance(err, grpc.RpcError):
            return False

        if self.retry_rate_limit_errors and err.code(
        ) == grpc.StatusCode.RESOURCE_EXHAUSTED:
            return True

        return retries <= 3 and (err.code() == grpc.StatusCode.INTERNAL
                                 or err.code() == grpc.StatusCode.UNAVAILABLE)

    def snapshot_at(self, snapshot_datetime):
        '''
        Constructs a read-only client that will provide historical data from the provided timestamp.

        See `SnapshotClient`.
        '''
        client = copy.copy(self)
        client.snapshot_datetime = snapshot_datetime
        client.access_requests = svc.AccessRequests(client.channel, client)
        client.account_attachments = svc.AccountAttachments(
            client.channel, client)
        client.account_grants = svc.AccountGrants(client.channel, client)
        client.account_permissions = svc.AccountPermissions(
            client.channel, client)
        client.account_resources = svc.AccountResources(client.channel, client)
        client.accounts = svc.Accounts(client.channel, client)
        client.accounts_groups = svc.AccountsGroups(client.channel, client)
        client.approval_workflow_approvers = svc.ApprovalWorkflowApprovers(
            client.channel, client)
        client.approval_workflow_steps = svc.ApprovalWorkflowSteps(
            client.channel, client)
        client.approval_workflows = svc.ApprovalWorkflows(
            client.channel, client)
        client.discovery_connectors = svc.DiscoveryConnectors(
            client.channel, client)
        client.roles = svc.Roles(client.channel, client)
        client.groups = svc.Groups(client.channel, client)
        client.groups_roles = svc.GroupsRoles(client.channel, client)
        client.identity_aliases = svc.IdentityAliases(client.channel, client)
        client.identity_sets = svc.IdentitySets(client.channel, client)
        client.nodes = svc.Nodes(client.channel, client)
        client.policies = svc.Policies(client.channel, client)
        client.proxy_cluster_keys = svc.ProxyClusterKeys(
            client.channel, client)
        client.remote_identities = svc.RemoteIdentities(client.channel, client)
        client.remote_identity_groups = svc.RemoteIdentityGroups(
            client.channel, client)
        client.resources = svc.Resources(client.channel, client)
        client.role_resources = svc.RoleResources(client.channel, client)
        client.secret_stores = svc.SecretStores(client.channel, client)
        client.workflow_approvers = svc.WorkflowApprovers(
            client.channel, client)
        client.workflow_roles = svc.WorkflowRoles(client.channel, client)
        client.workflows = svc.Workflows(client.channel, client)
        return SnapshotClient(client)


class SnapshotClient:
    '''SnapshotClient exposes methods to query historical records at a provided timestamp.'''
    def __init__(self, client):
        self.access_requests = svc.SnapshotAccessRequests(
            client.access_requests)
        '''
         AccessRequests are requests for access to a resource that may match a Workflow.

        See `strongdm.svc.SnapshotAccessRequests`.
        '''
        self.account_attachments = svc.SnapshotAccountAttachments(
            client.account_attachments)
        '''
         AccountAttachments assign an account to a role.

        See `strongdm.svc.SnapshotAccountAttachments`.
        '''
        self.account_grants = svc.SnapshotAccountGrants(client.account_grants)
        '''
         AccountGrants assign a resource directly to an account, giving the account the permission to connect to that resource.

        See `strongdm.svc.SnapshotAccountGrants`.
        '''
        self.account_permissions = svc.SnapshotAccountPermissions(
            client.account_permissions)
        '''
         AccountPermissions records the granular permissions accounts have, allowing them to execute
         relevant commands via StrongDM's APIs.

        See `strongdm.svc.SnapshotAccountPermissions`.
        '''
        self.account_resources = svc.SnapshotAccountResources(
            client.account_resources)
        '''
         AccountResources enumerates the resources to which accounts have access.
         The AccountResources service is read-only.

        See `strongdm.svc.SnapshotAccountResources`.
        '''
        self.accounts = svc.SnapshotAccounts(client.accounts)
        '''
         Accounts are users that have access to strongDM. There are two types of accounts:
         1. **Users:** humans who are authenticated through username and password or SSO.
         2. **Service Accounts:** machines that are authenticated using a service token.
         3. **Tokens** are access keys with permissions that can be used for authentication.

        See `strongdm.svc.SnapshotAccounts`.
        '''
        self.accounts_groups = svc.SnapshotAccountsGroups(
            client.accounts_groups)
        '''
         An AccountGroup links an account and a group.

        See `strongdm.svc.SnapshotAccountsGroups`.
        '''
        self.approval_workflow_approvers = svc.SnapshotApprovalWorkflowApprovers(
            client.approval_workflow_approvers)
        '''
         ApprovalWorkflowApprovers link approval workflow approvers to an ApprovalWorkflowStep

        See `strongdm.svc.SnapshotApprovalWorkflowApprovers`.
        '''
        self.approval_workflow_steps = svc.SnapshotApprovalWorkflowSteps(
            client.approval_workflow_steps)
        '''
         ApprovalWorkflowSteps link approval workflow steps to an ApprovalWorkflow

        See `strongdm.svc.SnapshotApprovalWorkflowSteps`.
        '''
        self.approval_workflows = svc.SnapshotApprovalWorkflows(
            client.approval_workflows)
        '''
         ApprovalWorkflows are the mechanism by which requests for access can be viewed by authorized
         approvers and be approved or denied.

        See `strongdm.svc.SnapshotApprovalWorkflows`.
        '''
        self.discovery_connectors = svc.SnapshotDiscoveryConnectors(
            client.discovery_connectors)
        '''
         A Discovery Connector is a configuration object for performing Resource
         Scans in remote systems such as AWS, GCP, Azure, and other systems.

        See `strongdm.svc.SnapshotDiscoveryConnectors`.
        '''
        self.roles = svc.SnapshotRoles(client.roles)
        '''
         A Role has a list of access rules which determine which Resources the members
         of the Role have access to. An Account can be a member of multiple Roles via
         AccountAttachments.

        See `strongdm.svc.SnapshotRoles`.
        '''
        self.groups = svc.SnapshotGroups(client.groups)
        '''
         A Group is a set of principals.

        See `strongdm.svc.SnapshotGroups`.
        '''
        self.groups_roles = svc.SnapshotGroupsRoles(client.groups_roles)
        '''
         A GroupRole is an assignment of a Group to a Role.

        See `strongdm.svc.SnapshotGroupsRoles`.
        '''
        self.identity_aliases = svc.SnapshotIdentityAliases(
            client.identity_aliases)
        '''
         IdentityAliases assign an alias to an account within an IdentitySet.
         The alias is used as the username when connecting to a identity supported resource.

        See `strongdm.svc.SnapshotIdentityAliases`.
        '''
        self.identity_sets = svc.SnapshotIdentitySets(client.identity_sets)
        '''
         A IdentitySet is a named grouping of Identity Aliases for Accounts.
         An Account's relationship to a IdentitySet is defined via IdentityAlias objects.

        See `strongdm.svc.SnapshotIdentitySets`.
        '''
        self.nodes = svc.SnapshotNodes(client.nodes)
        '''
         Nodes make up the StrongDM network, and allow your users to connect securely to your resources.
         There are three types of nodes:
         1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
         2. **Gateway:** a relay that also listens for connections from StrongDM clients
         3. **Proxy Cluster:** a cluster of workers that together mediate access from clients to resources

        See `strongdm.svc.SnapshotNodes`.
        '''
        self.policies = svc.SnapshotPolicies(client.policies)
        '''
         Policies are the collection of one or more statements that enforce fine-grained access
         control for the users of an organization.

        See `strongdm.svc.SnapshotPolicies`.
        '''
        self.proxy_cluster_keys = svc.SnapshotProxyClusterKeys(
            client.proxy_cluster_keys)
        '''
         Proxy Cluster Keys are authentication keys for all proxies within a cluster.
         The proxies within a cluster share the same key. One cluster can have
         multiple keys in order to facilitate key rotation.

        See `strongdm.svc.SnapshotProxyClusterKeys`.
        '''
        self.remote_identities = svc.SnapshotRemoteIdentities(
            client.remote_identities)
        '''
         RemoteIdentities assign a resource directly to an account, giving the account the permission to connect to that resource.

        See `strongdm.svc.SnapshotRemoteIdentities`.
        '''
        self.remote_identity_groups = svc.SnapshotRemoteIdentityGroups(
            client.remote_identity_groups)
        '''
         A RemoteIdentityGroup is a named grouping of Remote Identities for Accounts.
         An Account's relationship to a RemoteIdentityGroup is defined via RemoteIdentity objects.

        See `strongdm.svc.SnapshotRemoteIdentityGroups`.
        '''
        self.resources = svc.SnapshotResources(client.resources)
        '''
         Resources are databases, servers, clusters, websites, or clouds that strongDM
         delegates access to.

        See `strongdm.svc.SnapshotResources`.
        '''
        self.role_resources = svc.SnapshotRoleResources(client.role_resources)
        '''
         RoleResources enumerates the resources to which roles have access.
         The RoleResources service is read-only.

        See `strongdm.svc.SnapshotRoleResources`.
        '''
        self.secret_stores = svc.SnapshotSecretStores(client.secret_stores)
        '''
         SecretStores are servers where resource secrets (passwords, keys) are stored.

        See `strongdm.svc.SnapshotSecretStores`.
        '''
        self.workflow_approvers = svc.SnapshotWorkflowApprovers(
            client.workflow_approvers)
        '''
         WorkflowApprovers is an account or a role with the ability to approve requests bound to a workflow.

        See `strongdm.svc.SnapshotWorkflowApprovers`.
        '''
        self.workflow_roles = svc.SnapshotWorkflowRoles(client.workflow_roles)
        '''
         WorkflowRole links a role to a workflow. The linked roles indicate which roles a user must be a part of
         to request access to a resource via the workflow.

        See `strongdm.svc.SnapshotWorkflowRoles`.
        '''
        self.workflows = svc.SnapshotWorkflows(client.workflows)
        '''
         Workflows are the collection of rules that define the resources to which access can be requested,
         the users that can request that access, and the mechanism for approving those requests which can either
         be automatic approval or a set of users authorized to approve the requests.

        See `strongdm.svc.SnapshotWorkflows`.
        '''



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: organization_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aorganization_history.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\roptions.proto\x1a\nspec.proto\"\x8d\x01\n\x1eOrganizationHistoryListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x88\x02\n\x1fOrganizationHistoryListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12:\n\x07history\x18\x02 \x03(\x0b\x32\x1d.v1.OrganizationHistoryRecordB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xdf\x01\n\x19OrganizationHistoryRecord\x12\x1f\n\x0b\x61\x63tivity_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\x0corganization\x18\x03 \x01(\x0b\x32\x10.v1.OrganizationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xa1\r\n\x0cOrganization\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rauth_provider\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x14idle_timeout_enabled\x18\x05 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12;\n\x0cidle_timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12+\n\x17session_timeout_enabled\x18\x07 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12>\n\x0fsession_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\x0bmfa_enabled\x18\t \x01(\x08\x42$\xf2\xf8\xb3\x07\x1f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x15\xc2\xf4\xb3\x07\x10\n\x02go\x12\nMFAEnabled\x12;\n\x0cmfa_provider\x18\n \x01(\tB%\xf2\xf8\xb3\x07 \xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x16\xc2\xf4\xb3\x07\x11\n\x02go\x12\x0bMFAProvider\x12(\n\x12log_remote_encoder\x18\x0b \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\'\n\x11log_local_storage\x18\x0c \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\'\n\x11log_local_encoder\x18\r \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x10log_local_format\x18\x0e \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x42\n\x0flog_tcp_address\x18\x0f \x01(\tB)\x18\x01\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x02go\x12\rLogTCPAddress\x12%\n\x0flog_socket_path\x18\x10 \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\rscim_provider\x18\x11 \x01(\tB&\xf2\xf8\xb3\x07!\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x17\xc2\xf4\xb3\x07\x12\n\x02go\x12\x0cSCIMProvider\x12&\n\x12websites_subdomain\x18\x12 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12h\n$ssh_certificate_authority_public_key\x18\x13 \x01(\tB:\xf2\xf8\xb3\x07\x35\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07+\xc2\xf4\xb3\x07&\n\x02go\x12 SSHCertificateAuthorityPublicKey\x12\x84\x01\n$ssh_certificate_authority_updated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampB:\xf2\xf8\xb3\x07\x35\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07+\xc2\xf4\xb3\x07&\n\x02go\x12 SSHCertificateAuthorityUpdatedAt\x12(\n\x14require_secret_store\x18\x15 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\x0fsensitive_label\x18\x16 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x11saml_metadata_url\x18\x17 \x01(\tB)\xf2\xf8\xb3\x07$\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x02go\x12\x0fSAMLMetadataURL\x12\x18\n\x04kind\x18\x18 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12%\n\x02id\x18\x19 \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12\"\n\x0eloopback_range\x18\x1a \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x14\x64\x65vice_trust_enabled\x18\x1b \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x15\x64\x65vice_trust_provider\x18\x1c \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x16\x65nforce_single_session\x18\x1d \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12%\n\x0f\x64iscard_replays\x18\x1e \x01(\x08\x42\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0epublic_key_pem\x18\x1f \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12-\n\nlog_config\x18  \x01(\x0b\x32\r.v1.LogConfigB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xc6\x02\n\tLogConfig\x12!\n\rlocal_storage\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rlocal_encoder\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12 \n\x0clocal_format\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x11local_tcp_address\x18\x04 \x01(\tB)\xf2\xf8\xb3\x07$\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x02go\x12\x0fLocalTCPAddress\x12%\n\x11local_socket_path\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\npublic_key\x18\x06 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x38\n\ncategories\x18\x07 \x01(\x0b\x32\x18.v1.LogCategoryConfigMapB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xbc\x03\n\x14LogCategoryConfigMap\x12/\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1e.v1.LogCategoryConfigMap.Entry\x1a[\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x15.v1.LogCategoryConfig:\x1d\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\r!json_gateway:\x95\x02\xfa\xf8\xb3\x07\x8f\x02\xca\xf3\xb3\x07\xf1\x01\xea\xf3\xb3\x07\x17log_category_config_map\xf2\xf3\xb3\x07\x1a\n\x02go\x12\x14LogCategoryConfigMap\xf2\xf3\xb3\x07\"\n\ngo_private\x12\x14LogCategoryConfigMap\xf2\xf3\xb3\x07$\n\x0cgo_terraform\x12\x14LogCategoryConfigMap\xf2\xf3\xb3\x07\x30\n\x04java\x12(java.util.Map<String, LogCategoryConfig>\xf2\xf3\xb3\x07,\n\x0cjson_gateway\x12\x1cmap[string]LogCategoryConfig\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\r!json_gateway\"o\n\x11LogCategoryConfig\x12\"\n\x0eremote_encoder\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x16remote_discard_replays\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xef\x01\n\x13OrganizationHistory\x12\x80\x01\n\x04List\x12\".v1.OrganizationHistoryListRequest\x1a#.v1.OrganizationHistoryListResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/organization-history\x1aU\xca\xf9\xb3\x07\x1e\xc2\xf9\xb3\x07\x19OrganizationHistoryRecord\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x97\x01\n\x19\x63om.strongdm.api.plumbingB\x1bOrganizationHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ORGANIZATIONHISTORYLISTREQUEST = DESCRIPTOR.message_types_by_name['OrganizationHistoryListRequest']
_ORGANIZATIONHISTORYLISTRESPONSE = DESCRIPTOR.message_types_by_name['OrganizationHistoryListResponse']
_ORGANIZATIONHISTORYRECORD = DESCRIPTOR.message_types_by_name['OrganizationHistoryRecord']
_ORGANIZATION = DESCRIPTOR.message_types_by_name['Organization']
_LOGCONFIG = DESCRIPTOR.message_types_by_name['LogConfig']
_LOGCATEGORYCONFIGMAP = DESCRIPTOR.message_types_by_name['LogCategoryConfigMap']
_LOGCATEGORYCONFIGMAP_ENTRY = _LOGCATEGORYCONFIGMAP.nested_types_by_name['Entry']
_LOGCATEGORYCONFIG = DESCRIPTOR.message_types_by_name['LogCategoryConfig']
OrganizationHistoryListRequest = _reflection.GeneratedProtocolMessageType('OrganizationHistoryListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATIONHISTORYLISTREQUEST,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.OrganizationHistoryListRequest)
  })
_sym_db.RegisterMessage(OrganizationHistoryListRequest)

OrganizationHistoryListResponse = _reflection.GeneratedProtocolMessageType('OrganizationHistoryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATIONHISTORYLISTRESPONSE,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.OrganizationHistoryListResponse)
  })
_sym_db.RegisterMessage(OrganizationHistoryListResponse)

OrganizationHistoryRecord = _reflection.GeneratedProtocolMessageType('OrganizationHistoryRecord', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATIONHISTORYRECORD,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.OrganizationHistoryRecord)
  })
_sym_db.RegisterMessage(OrganizationHistoryRecord)

Organization = _reflection.GeneratedProtocolMessageType('Organization', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATION,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.Organization)
  })
_sym_db.RegisterMessage(Organization)

LogConfig = _reflection.GeneratedProtocolMessageType('LogConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOGCONFIG,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.LogConfig)
  })
_sym_db.RegisterMessage(LogConfig)

LogCategoryConfigMap = _reflection.GeneratedProtocolMessageType('LogCategoryConfigMap', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _LOGCATEGORYCONFIGMAP_ENTRY,
    '__module__' : 'organization_history_pb2'
    # @@protoc_insertion_point(class_scope:v1.LogCategoryConfigMap.Entry)
    })
  ,
  'DESCRIPTOR' : _LOGCATEGORYCONFIGMAP,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.LogCategoryConfigMap)
  })
_sym_db.RegisterMessage(LogCategoryConfigMap)
_sym_db.RegisterMessage(LogCategoryConfigMap.Entry)

LogCategoryConfig = _reflection.GeneratedProtocolMessageType('LogCategoryConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOGCATEGORYCONFIG,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.LogCategoryConfig)
  })
_sym_db.RegisterMessage(LogCategoryConfig)

_ORGANIZATIONHISTORY = DESCRIPTOR.services_by_name['OrganizationHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\033OrganizationHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ORGANIZATIONHISTORYLISTREQUEST.fields_by_name['filter']._options = None
  _ORGANIZATIONHISTORYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYLISTREQUEST._options = None
  _ORGANIZATIONHISTORYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['history']._options = None
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['history']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ORGANIZATIONHISTORYLISTRESPONSE._options = None
  _ORGANIZATIONHISTORYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ORGANIZATIONHISTORYRECORD.fields_by_name['activity_id']._options = None
  _ORGANIZATIONHISTORYRECORD.fields_by_name['activity_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYRECORD.fields_by_name['timestamp']._options = None
  _ORGANIZATIONHISTORYRECORD.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYRECORD.fields_by_name['organization']._options = None
  _ORGANIZATIONHISTORYRECORD.fields_by_name['organization']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYRECORD._options = None
  _ORGANIZATIONHISTORYRECORD._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ORGANIZATION.fields_by_name['name']._options = None
  _ORGANIZATION.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['created_at']._options = None
  _ORGANIZATION.fields_by_name['created_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['updated_at']._options = None
  _ORGANIZATION.fields_by_name['updated_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['auth_provider']._options = None
  _ORGANIZATION.fields_by_name['auth_provider']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['idle_timeout_enabled']._options = None
  _ORGANIZATION.fields_by_name['idle_timeout_enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['idle_timeout']._options = None
  _ORGANIZATION.fields_by_name['idle_timeout']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['session_timeout_enabled']._options = None
  _ORGANIZATION.fields_by_name['session_timeout_enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['session_timeout']._options = None
  _ORGANIZATION.fields_by_name['session_timeout']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['mfa_enabled']._options = None
  _ORGANIZATION.fields_by_name['mfa_enabled']._serialized_options = b'\362\370\263\007\037\260\363\263\007\001\312\363\263\007\025\302\364\263\007\020\n\002go\022\nMFAEnabled'
  _ORGANIZATION.fields_by_name['mfa_provider']._options = None
  _ORGANIZATION.fields_by_name['mfa_provider']._serialized_options = b'\362\370\263\007 \260\363\263\007\001\312\363\263\007\026\302\364\263\007\021\n\002go\022\013MFAProvider'
  _ORGANIZATION.fields_by_name['log_remote_encoder']._options = None
  _ORGANIZATION.fields_by_name['log_remote_encoder']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_local_storage']._options = None
  _ORGANIZATION.fields_by_name['log_local_storage']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_local_encoder']._options = None
  _ORGANIZATION.fields_by_name['log_local_encoder']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_local_format']._options = None
  _ORGANIZATION.fields_by_name['log_local_format']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_tcp_address']._options = None
  _ORGANIZATION.fields_by_name['log_tcp_address']._serialized_options = b'\030\001\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\002go\022\rLogTCPAddress'
  _ORGANIZATION.fields_by_name['log_socket_path']._options = None
  _ORGANIZATION.fields_by_name['log_socket_path']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['scim_provider']._options = None
  _ORGANIZATION.fields_by_name['scim_provider']._serialized_options = b'\362\370\263\007!\260\363\263\007\001\312\363\263\007\027\302\364\263\007\022\n\002go\022\014SCIMProvider'
  _ORGANIZATION.fields_by_name['websites_subdomain']._options = None
  _ORGANIZATION.fields_by_name['websites_subdomain']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_public_key']._options = None
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_public_key']._serialized_options = b'\362\370\263\0075\260\363\263\007\001\312\363\263\007+\302\364\263\007&\n\002go\022 SSHCertificateAuthorityPublicKey'
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_updated_at']._options = None
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_updated_at']._serialized_options = b'\362\370\263\0075\260\363\263\007\001\312\363\263\007+\302\364\263\007&\n\002go\022 SSHCertificateAuthorityUpdatedAt'
  _ORGANIZATION.fields_by_name['require_secret_store']._options = None
  _ORGANIZATION.fields_by_name['require_secret_store']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['sensitive_label']._options = None
  _ORGANIZATION.fields_by_name['sensitive_label']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['saml_metadata_url']._options = None
  _ORGANIZATION.fields_by_name['saml_metadata_url']._serialized_options = b'\362\370\263\007$\260\363\263\007\001\312\363\263\007\032\302\364\263\007\025\n\002go\022\017SAMLMetadataURL'
  _ORGANIZATION.fields_by_name['kind']._options = None
  _ORGANIZATION.fields_by_name['kind']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['id']._options = None
  _ORGANIZATION.fields_by_name['id']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _ORGANIZATION.fields_by_name['loopback_range']._options = None
  _ORGANIZATION.fields_by_name['loopback_range']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['device_trust_enabled']._options = None
  _ORGANIZATION.fields_by_name['device_trust_enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['device_trust_provider']._options = None
  _ORGANIZATION.fields_by_name['device_trust_provider']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['enforce_single_session']._options = None
  _ORGANIZATION.fields_by_name['enforce_single_session']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['discard_replays']._options = None
  _ORGANIZATION.fields_by_name['discard_replays']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['public_key_pem']._options = None
  _ORGANIZATION.fields_by_name['public_key_pem']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_config']._options = None
  _ORGANIZATION.fields_by_name['log_config']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION._options = None
  _ORGANIZATION._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _LOGCONFIG.fields_by_name['local_storage']._options = None
  _LOGCONFIG.fields_by_name['local_storage']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['local_encoder']._options = None
  _LOGCONFIG.fields_by_name['local_encoder']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['local_format']._options = None
  _LOGCONFIG.fields_by_name['local_format']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['local_tcp_address']._options = None
  _LOGCONFIG.fields_by_name['local_tcp_address']._serialized_options = b'\362\370\263\007$\260\363\263\007\001\312\363\263\007\032\302\364\263\007\025\n\002go\022\017LocalTCPAddress'
  _LOGCONFIG.fields_by_name['local_socket_path']._options = None
  _LOGCONFIG.fields_by_name['local_socket_path']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['public_key']._options = None
  _LOGCONFIG.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['categories']._options = None
  _LOGCONFIG.fields_by_name['categories']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG._options = None
  _LOGCONFIG._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _LOGCATEGORYCONFIGMAP_ENTRY._options = None
  _LOGCATEGORYCONFIGMAP_ENTRY._serialized_options = b'\372\370\263\007\030\322\363\263\007\001*\322\363\263\007\r!json_gateway'
  _LOGCATEGORYCONFIGMAP._options = None
  _LOGCATEGORYCONFIGMAP._serialized_options = b'\372\370\263\007\217\002\312\363\263\007\361\001\352\363\263\007\027log_category_config_map\362\363\263\007\032\n\002go\022\024LogCategoryConfigMap\362\363\263\007\"\n\ngo_private\022\024LogCategoryConfigMap\362\363\263\007$\n\014go_terraform\022\024LogCategoryConfigMap\362\363\263\0070\n\004java\022(java.util.Map<String, LogCategoryConfig>\362\363\263\007,\n\014json_gateway\022\034map[string]LogCategoryConfig\322\363\263\007\001*\322\363\263\007\r!json_gateway'
  _LOGCATEGORYCONFIG.fields_by_name['remote_encoder']._options = None
  _LOGCATEGORYCONFIG.fields_by_name['remote_encoder']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCATEGORYCONFIG.fields_by_name['remote_discard_replays']._options = None
  _LOGCATEGORYCONFIG.fields_by_name['remote_discard_replays']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCATEGORYCONFIG._options = None
  _LOGCATEGORYCONFIG._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ORGANIZATIONHISTORY._options = None
  _ORGANIZATIONHISTORY._serialized_options = b'\312\371\263\007\036\302\371\263\007\031OrganizationHistoryRecord\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _ORGANIZATIONHISTORY.methods_by_name['List']._options = None
  _ORGANIZATIONHISTORY.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/organization-history'
  _ORGANIZATIONHISTORYLISTREQUEST._serialized_start=127
  _ORGANIZATIONHISTORYLISTREQUEST._serialized_end=268
  _ORGANIZATIONHISTORYLISTRESPONSE._serialized_start=271
  _ORGANIZATIONHISTORYLISTRESPONSE._serialized_end=535
  _ORGANIZATIONHISTORYRECORD._serialized_start=538
  _ORGANIZATIONHISTORYRECORD._serialized_end=761
  _ORGANIZATION._serialized_start=764
  _ORGANIZATION._serialized_end=2461
  _LOGCONFIG._serialized_start=2464
  _LOGCONFIG._serialized_end=2790
  _LOGCATEGORYCONFIGMAP._serialized_start=2793
  _LOGCATEGORYCONFIGMAP._serialized_end=3237
  _LOGCATEGORYCONFIGMAP_ENTRY._serialized_start=2866
  _LOGCATEGORYCONFIGMAP_ENTRY._serialized_end=2957
  _LOGCATEGORYCONFIG._serialized_start=3239
  _LOGCATEGORYCONFIG._serialized_end=3350
  _ORGANIZATIONHISTORY._serialized_start=3353
  _ORGANIZATIONHISTORY._serialized_end=3592
# @@protoc_insertion_point(module_scope)
